@@ -13,23 +13,29 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
 	my ($class, @params) = @_;
 	my $self = bless {}, $class;
 
-	# Parse handlers.
-	$self->{'attribute'} = undef;
-	$self->{'comment'} = undef;
-	$self->{'data'} = undef;
-	$self->{'end_tag'} = undef;
-	$self->{'final'} = undef;
-	$self->{'init'} = undef;
-	$self->{'instruction'} = undef;
-	$self->{'start_tag'} = undef;
-	$self->{'other'} = undef;
+	# Parse callbacks.
+	$self->{'callbacks'} = {
+		'attribute' => undef,
+		'comment' => undef,
+		'data' => undef,
+		'end_element' => undef,
+		'final' => undef,
+		'init' => undef,
+		'instruction' => undef,
+		'rewrite' => undef,
+		'start_element' => undef,
+		'other' => undef,
+	},
+
+	# Non parser options.
+	$self->{'non_parser_options'} = {};
 
 	# Output rewrite.
 	$self->{'output_rewrite'} = 0;
@@ -40,8 +46,15 @@ sub new {
 	# Process params.
 	set_params($self, @params);
 
+	# Check output handler.
+	if (defined $self->{'output_handler'}
+		&& ref $self->{'output_handler'} ne 'GLOB') {
+
+		err 'Bad output handler.';
+	}
+
 	# Processing line.
-	$self->{'line'} = $EMPTY_STR;
+	$self->{'_line'} = $EMPTY_STR;
 
 	# Object.
 	return $self;
@@ -50,7 +63,7 @@ sub new {
 # Parse PYX text or array of PYX text.
 sub parse {
 	my ($self, $pyx, $out) = @_;
-	if (! $out) {
+	if (! defined $out) {
 		$out = $self->{'output_handler'};
 	}
 
@@ -63,14 +76,14 @@ sub parse {
 	}
 
 	# Parse.
-	if ($self->{'init'}) {
-		&{$self->{'init'}}($self);
+	if ($self->{'callbacks'}->{'init'}) {
+		&{$self->{'callbacks'}->{'init'}}($self);
 	}
 	foreach my $line (@text) {
 		$self->_parse($line, $out);
 	}
-	if ($self->{'final'}) {
-		&{$self->{'final'}}($self);
+	if ($self->{'callbacks'}->{'final'}) {
+		&{$self->{'callbacks'}->{'final'}}($self);
 	}
 	return;
 }
@@ -90,18 +103,18 @@ sub parse_handler {
 	if (! $input_file_handler || ref $input_file_handler ne 'GLOB') {
 		err 'No input handler.';
 	}
-	if (! $out) {
+	if (! defined $out) {
 		$out = $self->{'output_handler'};
 	}
-	if ($self->{'init'}) {
-		&{$self->{'init'}}($self);
+	if ($self->{'callbacks'}->{'init'}) {
+		&{$self->{'callbacks'}->{'init'}}($self);
 	}
 	while (my $line = <$input_file_handler>) {
 		chomp $line;
 		$self->_parse($line, $out);
 	}
-	if ($self->{'final'}) {
-		&{$self->{'final'}}($self);
+	if ($self->{'callbacks'}->{'final'}) {
+		&{$self->{'callbacks'}->{'final'}}($self);
 	}
 	return;
 }
@@ -109,7 +122,7 @@ sub parse_handler {
 # Parse text string.
 sub _parse {
 	my ($self, $line, $out) = @_;
-	$self->{'line'} = $line;
+	$self->{'_line'} = $line;
 	my ($type, $value) = $line =~ m/\A([A()\?\-_])(.*)\Z/;
 	if (! $type) { 
 		$type = 'X';
@@ -120,13 +133,13 @@ sub _parse {
 		my ($att, $attval) = $line =~ m/\AA([^\s]+)\s*(.*)\Z/;
 		$self->_is_sub('attribute', $out, $att, $attval);
 
-	# Start of tag.
+	# Start of element.
 	} elsif ($type eq '(') {
-		$self->_is_sub('start_tag', $out, $value);
+		$self->_is_sub('start_element', $out, $value);
 
-	# End of tag.
+	# End of element.
 	} elsif ($type eq ')') {
-		$self->_is_sub('end_tag', $out, $value);
+		$self->_is_sub('end_element', $out, $value);
 
 	# Data.
 	} elsif ($type eq '-') {
@@ -143,32 +156,34 @@ sub _parse {
 
 	# Others.
 	} else {
-		if ($self->{'other'}) {
-			&{$self->{'other'}}($self, $line);
+		if ($self->{'callbacks'}->{'other'}) {
+			&{$self->{'callbacks'}->{'other'}}($self, $line);
 		} else {
-			err "Bad PYX tag at line '$line'.";
+			err "Bad PYX line '$line'.";
 		}
 	}
 	return;
 }
 
-# Helper to defined handlers.
+# Helper to defined callbacks.
 sub _is_sub {
 	my ($self, $key, $out, @values) = @_;
 
-	# Handler with name '$key'.
-	if (exists $self->{$key} && ref $self->{$key} eq 'CODE') {
-		&{$self->{$key}}($self, @values);
+	# Callback with name '$key'.
+	if (exists $self->{'callbacks'}->{$key}
+		&& ref $self->{'callbacks'}->{$key} eq 'CODE') {
 
-	# Handler rewrite.
-	} elsif (exists $self->{'rewrite'} 
-		&& ref $self->{'rewrite'} eq 'CODE') {
+		&{$self->{'callbacks'}->{$key}}($self, @values);
 
-		&{$self->{'rewrite'}}($self, $self->{'line'});
+	# Rewrite callback.
+	} elsif (exists $self->{'callbacks'}->{'rewrite'} 
+		&& ref $self->{'callbacks'}->{'rewrite'} eq 'CODE') {
 
-	# Raw output to output handler handler.
+		&{$self->{'callbacks'}->{'rewrite'}}($self, $self->{'_line'});
+
+	# Raw output to output file handler.
 	} elsif ($self->{'output_rewrite'}) {
-		print {$out} $self->{'line'}, "\n";
+		print {$out} $self->{'_line'}, "\n";
 	}
 	return;
 }
@@ -183,15 +198,15 @@ __END__
 
 =head1 NAME
 
-PYX::Parser - PYX parser with handlers.
+PYX::Parser - PYX parser with callbacks.
 
 =head1 SYNOPSIS
 
-use PYX::Parser;
-my $obj = PYX::Parser->new(%parameters);
-$obj->parse($pyx, $out);
-$obj->parse_file($input_file, $out);
-$obj->parse_handle($input_file_handler, $out);
+ use PYX::Parser;
+ my $obj = PYX::Parser->new(%parameters);
+ $obj->parse($pyx, $out);
+ $obj->parse_file($input_file, $out);
+ $obj->parse_handle($input_file_handler, $out);
 
 =head1 METHODS
 
@@ -203,46 +218,70 @@ $obj->parse_handle($input_file_handler, $out);
 
 =over 8
 
+=item * C<callbacks>
+
+ Callbacks.
+
+=over 8
+
 =item * C<attribute>
 
- Attribute handler.
+ Attribute callback.
  Default value is undef.
 
 =item * C<comment>
 
- Comment handler.
+ Comment callback.
  Default value is undef.
 
 =item * C<data>
 
- Data handler.
+ Data callback.
  Default value is undef.
 
-=item * C<end_tag>
+=item * C<end_element>
 
- End of tag handler.
+ End of element callback.
  Default value is undef.
 
 =item * C<final>
 
- Final handler.
+ Final callback.
  Default value is undef.
 
 =item * C<init>
 
- Init handler.
+ Init callback.
  Default value is undef.
 
 =item * C<instruction>
 
- Instruction handler.
+ Instruction callback.
  Default value is undef.
 
-=item * C<start_tag>
+=item * C<rewrite>
 
- Start of tag handler.
+ Rewrite callback.
+ Callback is used on every line.
  Default value is undef.
 
+=item * C<start_element>
+
+ Start of element callback.
+ Default value is undef.
+
+=item * C<other>
+
+ Other Callback.
+ Default value is undef.
+
+=back
+
+=item * C<non_parser_options>
+
+ Non parser options.
+ Default value is blank reference to hash.
+
 =item * C<output_rewrite>
 
  Output rewrite.
@@ -253,11 +292,6 @@ $obj->parse_handle($input_file_handler, $out);
  Output handler.
  Default value is \*STDOUT.
 
-=item * C<other>
-
- Other handler.
- Default value is undef.
-
 =back
 
 =item C<parse($pyx[, $out])>
@@ -283,18 +317,19 @@ $obj->parse_handle($input_file_handler, $out);
 =head1 ERRORS
 
  new():
+         Bad output handler.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
 
  parse():
-         Bad PYX tag at line '%s'.
+         Bad PYX line '%s'.
 
  parse_file():
-         Bad PYX tag at line '%s'.
+         Bad PYX line '%s'.
          No input handler.
 
  parse_handler():
-         Bad PYX tag at line '%s'.
+         Bad PYX line '%s'.
          No input handler.
 
 =head1 EXAMPLE
@@ -318,8 +353,10 @@ $obj->parse_handle($input_file_handler, $out);
  
  # PYX::Parser object.
  my $parser = PYX::Parser->new(
-        'start_tag' => \&start_tag,
-        'end_tag' => \&end_tag,
+	'callbacks' => {
+        	'start_element' => \&start_element,
+        	'end_element' => \&end_element,
+	},
  );
  $parser->parse_handler($file_handler);
  
@@ -328,16 +365,18 @@ $obj->parse_handle($input_file_handler, $out);
         close(INF);
  }
  
- # Start tag handler.
- sub start_tag {
-        my ($self, $tag) = @_;
-        print "Start of tag '$tag'.\n";
+ # Start element callback.
+ sub start_element {
+        my ($self, $elem) = @_;
+        print "Start of element '$elem'.\n";
+        return;
  }
 
- # End tag handler.
- sub end_tag {
-        my ($self, $tag) = @_;
-        print "End of tag '$tag'.\n";
+ # End element callback.
+ sub end_element {
+        my ($self, $elem) = @_;
+        print "End of element '$elem'.\n";
+        return;
  }
 
 =head1 DEPENDENCIES
@@ -352,14 +391,17 @@ L<PYX::Utils>.
 
 =head1 AUTHOR
 
-Michal Špaček L<skim@cpan.org>.
+Michal Špaček L<mailto:skim@cpan.org>
+
+L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
